@@ -4,17 +4,20 @@ knitr::opts_chunk$set(fig.width=7, fig.height=7, comment="")
 
 ## ------------------------------------------------------------------------
 library(repo)
-
-## ------------------------------------------------------------------------
 rp <- repo_open(tempdir(), force=T)
 
 ## ------------------------------------------------------------------------
-rp$attach("index.Rmd", "Source code for Repo vignette", c("source","Rmd"))
+rp$attach("index.Rmd", "Source code for Repo vignette", replace=T)
+rp$options(src="index.Rmd")
 
 ## ------------------------------------------------------------------------
 myiris <- scale(as.matrix(iris[,1:4]))
 
 ## ------------------------------------------------------------------------
+rp$put(myiris)
+
+## ------------------------------------------------------------------------
+## chunk "myiris" {
 rp$put(
     obj = myiris,
     name = "myiris", 
@@ -23,13 +26,21 @@ rp$put(
         "Normalization is made with the scale function",
         "with default parameters."
     ),
-    tags = c("dataset", "iris", "repodemo"), 
-    src = "index.Rmd"
+    tags = c("dataset", "iris", "repodemo"),
+    replace=T
 )
+## }
 
 ## ------------------------------------------------------------------------
-rp$put(iris$Species, "irisLabels", "The Iris class lables.",
-         c("labels", "iris", "repodemo"), "index.Rmd")
+rp$chunk("myiris")
+
+## ------------------------------------------------------------------------
+rp$rm("myiris")
+rp$build("myiris", "index.Rmd")
+
+## ------------------------------------------------------------------------
+rp$put(iris$Species, "irisLabels",
+		     tags = c("labels", "iris", "repodemo"))
 
 ## ------------------------------------------------------------------------
 irispca <- princomp(myiris)
@@ -45,31 +56,16 @@ plot(iris2d, main="2D visualization of the Iris dataset",
 invisible(dev.off())
 rp$attach(fpath, "Iris 2D visualization obtained with PCA.",
             c("visualization", "iris", "repodemo"),
-              "index.Rmd", to="myiris")
+              to="myiris")
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  rp$sys("iris2D.pdf", "evince")
 
-## ---- eval=FALSE---------------------------------------------------------
-#  rp$sys("index.Rmd", "evince")
-
-## ------------------------------------------------------------------------
-plot(irispca)
-
-## ------------------------------------------------------------------------
-fpath <- file.path(rp$root(), "irisPCA.pdf")
-pdf(fpath)
-plot(irispca)
-invisible(dev.off())
-rp$attach(fpath, "Variance explained by the PCs of the Iris dataset",
-            c("visualization", "iris", "repodemo"),
-              "index.Rmd", to="iris2D.pdf")
-
 ## ------------------------------------------------------------------------
 kiris <- kmeans(myiris, 5)$cluster
 rp$put(kiris, "iris_5clu", "Kmeans clustering of the Iris data, k=5.",
          c("metadata", "iris", "kmeans", "clustering", "repodemo"),
-           "index.Rmd", depends="myiris", T)
+           depends="myiris")
 
 ## ------------------------------------------------------------------------
 plot(iris2d, main="Iris dataset kmeans clustering", col=kiris)
@@ -81,7 +77,7 @@ plot(iris2d, main="Iris dataset kmeans clustering", col=kiris)
 invisible(dev.off())
 rp$attach(fpath, "Iris K-means clustering.",
 	c("visualization", "iris", "clustering", "kmeans", "repodemo"),
-	"index.Rmd", to="iris_5clu")
+	 		   to="iris_5clu")
 
 ## ------------------------------------------------------------------------
 res <- table(rp$get("irisLabels"), kiris)
@@ -89,7 +85,7 @@ rp$put(res, "iris_cluVsSpecies",
          paste("Contingency table of the kmeans clustering versus the",
                "original labels of the Iris dataset."),
          c("result", "iris","validation", "clustering", "repodemo", "hide"),
-         "index.Rmd", c("myiris", "irisLabels", "iris_5clu"), T)
+         src="index.Rmd", depends=c("myiris", "irisLabels", "iris_5clu"), replace=T)
 
 ## ------------------------------------------------------------------------
 rp$info()
@@ -103,12 +99,6 @@ print(rp, all=T)
 ## ------------------------------------------------------------------------
 print(rp, tags="clustering", all=T)
 
-## ------------------------------------------------------------------------
-print(rp, tags="attachment", all=T)
-
-## ------------------------------------------------------------------------
-print(rp, tags="hide", all=T)
-
 ## ------------------------------------------------------------------------
 rp$print(show="st")
 
@@ -118,36 +108,38 @@ rp$find("clu", all=T)
 ## ------------------------------------------------------------------------
 rp$pies()
 
-## ---- eval=F-------------------------------------------------------------
-#  rp$cpanel()
-
 ## ------------------------------------------------------------------------
 rp$check()
 
 ## ------------------------------------------------------------------------
 depgraph <- rp$dependencies(plot=F)
-rownames(depgraph) <- colnames(depgraph) <- basename(rownames(depgraph))
 library(knitr)
 kable(depgraph)
 
 ## ------------------------------------------------------------------------
-rp$dependencies()
+if(require("igraph", NULL, T, F))
+     rp$dependencies()
 
 ## ------------------------------------------------------------------------
-rp$dependencies(generated=F)
+if(require("igraph"))
+    rp$dependencies(generated=F)
 
 ## ------------------------------------------------------------------------
 x <- rp$get("myiris")
 
+## ------------------------------------------------------------------------
+rm("myiris")
+rp$load("myiris")
+"myiris" %in% ls()
+
 ## ------------------------------------------------------------------------
 rp$info("myiris")
 
 ## ------------------------------------------------------------------------
 kiris2 <- kmeans(myiris, 5)$cluster
-rp$put(kiris, "iris_5clu",
+rp$put(kiris2, "iris_5clu",
          "Kmeans clustering of the Iris data, k=5. Today's version!",
-         c("metadata", "iris", "kmeans", "clustering", "repodemo"),
-           "index.Rmd", depends="myiris", replace="addversion")
+           depends="myiris", replace="addversion")
 
 ## ------------------------------------------------------------------------
 rp
@@ -155,27 +147,9 @@ rp
 ## ------------------------------------------------------------------------
 rp$info("iris_5clu")
 
-## ------------------------------------------------------------------------
-rp$print(all=T)
-
 ## ------------------------------------------------------------------------
 rp$info("iris_5clu#1")
 
-## ----include=FALSE-------------------------------------------------------
-dorun <- FALSE
-result <- "This took 10 seconds to compute"
-rp$stash(result)
-
-## ------------------------------------------------------------------------
-if(dorun) {
-    Sys.sleep(10)
-    result <- "This took 10 seconds to compute"
-    rp$stash(result)
-} else result <- rp$get("result")
-
-## ------------------------------------------------------------------------
-rp$info("result")
-
 ## ------------------------------------------------------------------------
 expr <- expression({
 	Sys.sleep(3)
@@ -188,9 +162,16 @@ system.time(rp$lazydo(expr)) # second run
 ## ------------------------------------------------------------------------
 rp$put("Local content", "item1",
 	"This points to big data you may want to download",
-	"tag", URL="http://www.francesconapolitano.it/repo/remote")
+	"tag", URL="http://exampleURL/repo")
 print(rp$get("item1"))
-rp$pull("item1", replace=T)
+
+## ---- eval=F-------------------------------------------------------------
+#  rp$pull("item1", replace=T)
+
+## ---- include=F----------------------------------------------------------
+rp$set("item1", obj="Remote content")
+
+## ------------------------------------------------------------------------
 print(rp$get("item1"))
 
 ## ------------------------------------------------------------------------
